==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/view_editace_dne.php <==
<?php

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

/** @var $this EditaceDneFormular */

$readonlystr = $this ->readOnly ? ' disabled="disabled" ' : '';

$backurl =
    '?menuid=' . ((isset($_SESSION['editace_backaction']) && $_SESSION['editace_backaction'] == 'rozdelenidv') ? 'rozdelenidv' : 'zpracovanadochazka') .
    '&idpp=' . $this ->pp ->idPP .
    '&obdobi=' . DateUtils::dateToUrlString(DateUtils::firstDayOfMonth($this ->den));

?>
<h1><?= TextManager::_('Editace_dochazky') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<form enctype="multipart/form-data" method="post" id="editaceDneForm" action="?menuid=editacedne&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>" class="sendPosition" >
    <!-- skryty submit button, protoze defaultni submit musi byt vzdy prvni (jinak by byl defaultni button pro smazani radku rozdeleni) -->
    <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" />

    <input type="hidden" name="idpp" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="datum" value="<?= $this ->den ?>" />
    <input type="hidden" name="ulozzaznamyproden" value="<?= $this ->readOnly ? 0 : 1 ?>" />
    <input type="hidden" name="ulozrozdelenivysledku" value="<?= $this ->povolitEditaciRozdeleni ? 1 : 0 ?>" />
    <input type="hidden" name="pocet" value="<?= count($this ->zaznamy) ?>" />
    <input type="hidden" name="zobrazitnovy" value="<?= $this ->zobrazitNovy ?>" />
    <input type="hidden" name="deleterow" id="editaceDneDeleteRow" value="" />
    <input type="hidden" name="x" />
    <input type="hidden" name="y" />

    <div class="form form-sm large-form" id="editaceDne">
        <div class="form-content">
            <!-- hlavicka -->
            <div class="row">
                <div class="col col-12 col-sm-3" style="white-space:nowrap">
                    <?php $this->zobrazSchvaleni($this->den); ?>
                </div>

                <div class="col col-7 d-xs-none">
                </div>

                <div class="col col-2 d-xs-none formFotoContainer">
                    <!-- foto -->
                    <?php if ($this ->pp ->idFotografie) { ?>
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    <?php } ?>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7">
                    <strong><?= $this->pp ->jmenoPrijmeni ?></strong>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-7">
                    <strong><?= TextManager::_('Day_short_' . date("w", $this ->den)) . ' ' . date('j.n.Y', $this ->den) ?></strong>
                    <?php if ($this ->obdobiUzavreno) { ?><div class="inline-glyph fa glyph-lock"></div><?php } ?>
                </div>
            </div>

            <div class="row form-gap d-xs-none">&nbsp;</div>

            <!-- zaznamy -->
            <div class="row form-section no-margin-bottom">
                <div class="col col-1"><?= TextManager::_('Od') ?></div>
                <div class="col col-1"><?= TextManager::_('Do') ?></div>
                <div class="col col-10"></div>
            </div>

            <?php foreach ($this ->zaznamy as $i => $zaznam) {

            $rowclassname = ($i % 2) ? 'browsercolor1' : 'browsercolor2';

            $classname_od = $zaznam ->chybaCasPocatku ? 'error' : '';
            $classname_do = $zaznam ->chybaCasKonce ? 'error' : '';
            ?>

                <div class="zaznamEditaceDne <?= $rowclassname ?>">
                    <div class="row">
                        <!-- cas od-do -->
                        <div class="col col-1">
                            <input type="hidden" name="datumcaspocatku<?= $i ?>" value="<?= $zaznam ->fDatumCasPocatku ->originalValue /* puvodni datum cas pocatku */ ?>" />
                            <input type="hidden" name="datumpocatku<?= $i ?>" value="<?= date('j.n.Y', $zaznam->fDatumCasPocatku ->value) ?>" /> <!-- pro js -->
                            <input type="text" class="form-input <?= $classname_od ?> inputTime" name="caspocatku<?= $i ?>" maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->casPocatkuStr) ?>" />
                        </div>
                        <div class="col col-1">
                            <input type="text" class="form-input <?= $classname_do ?> inputTime" name="casukonceni<?= $i ?>" maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->casKonceStr) ?>" />
                        </div>

                        <!-- den prirazeni -->
                        <div class="col col-2 caption"><?= TextManager::_('Den_prirazeni') ?></div>
                        <div class="col col-5">
                            <input type="text" class="<?= $zaznam->chybaDen ? 'error' : '' ?> inputDate" name="den<?= $i ?>"
                                   maxlength="10" size="10" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->denStr) ?>"
                                   data-roncalendar-mindate="<?= date('j.n.Y', DateUtils::incDay($zaznam ->fDatumCasPocatku ->value, -1) ) ?>"
                                   data-roncalendar-maxdate="<?= date('j.n.Y', DateUtils::incDay($zaznam ->fDatumCasPocatku ->value, 1) ) ?>"
                                />
                            <i class="inline-glyph glyph-button fa glyph-calendar showcalendar" data-roncalendar-inputname="den<?= $i ?>"></i>
                        </div>
                        <div class="col col-2 align-right">
                            <?= StringUtils::htmlTextConvert($zaznam ->fZpracoval ->value) ?>
                        </div>
                        <div class="col col-1 align-right">
                            <?php if (!$this ->readOnly) { ?>
                            <i class="inline-glyph glyph-button fa glyph-delete deleteRecord" data-index="<?= $i ?>"  data-ron-confirm-text="<?= TextManager::_('Opravdu_smazat_zaznam_dochazky') ?>"></i>
                            <?php } ?>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col col-2"><?= RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY) ? '' : TextManager::_('Zapocteno') ?></div>

                        <!-- operace -->
                        <div class="col col-2 caption"><?= TextManager::_('Operace') ?></div>
                        <div class="col col-5">
                            <?php $this->showVyberOperace($zaznam ->f_operace ->value, $i, false); ?>
                        </div>
                        <div class="col col-3">
                            <?php $this->showVyberOperace($zaznam ->f_operace ->value, $i, true); ?>
                        </div>
                    </div>


                    <div class="row">
                        <!-- zapocteny cas -->
                        <div class="col col-1">
                            <?php if (!RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY)) { ?>
                                <input type="text" class="form-input <?= $zaznam->chybaZapoctenyCasOd ? 'error' : '' ?>" name="zapoctenycasod<?= $i ?>"
                                       maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->zapoctenyCasOdStr) ?>" />
                            <?php } ?>
                        </div>
                        <div class="col col-1">
                            <?php if (!RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY)) { ?>
                                <input type="text" class="form-input <?= $zaznam->chybaZapoctenyCasDo ? 'error' : '' ?>" name="zapoctenycasdo<?= $i ?>"
                                       maxlength="5" size="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->zapoctenyCasDoStr) ?>" />
                            <?php } ?>
                        </div>

                        <div class="col col-2 caption"><?= TextManager::_('Smena') ?></div>
                        <div class="col col-8"><?php  $this ->showVyberSmeny($zaznam, 'smena' . $i); ?></div>
                    </div>

                    <?php
                    // pripadne jeste stredisko (rozdeleni)
                    if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) { ?>
                        <div class="row">
                            <div class="col col-2 d-xs-none"></div>

                            <!-- vyber rozdeleni -->
                            <div class="col col-12 col-sm-2 caption"><?= RonPortalSettings::getValue(RonPortalSettings::EDITACE_NADPIS_ROZDELENI) ?: TextManager::_('Rozdeleni') ?></div>
                            <div class="col col-8 col-sm-5">
                                <?php $this->showVyberRozdeleni($zaznam, 'rozdelenidochazky' . $i, false); ?>
                            </div>
                            <div class="col col-4 col-sm-3">
                                <?php $this->showVyberRozdeleni($zaznam, 'rozdelenidochazky' . $i, true); ?>
                            </div>
                        </div>
                    <?php } ?>

                    <div class="row">
                        <div class="col col-2 d-xs-none"></div>

                        <div class="col col-12 col-sm-2 caption"><?= TextManager::_('Poznamka') ?></div>
                        <div class="col col-12 col-sm-8">
                            <input type="text" class="form-input" name="poznamka<?= $i ?>" maxlength="160" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->poznamka) ?>" />
                        </div>
                    </div>
                </div>
            <?php } ?>

            <div class="align-right">
                <?php if (!$this ->readOnly  &&  RonPortalSettings::getSpousteniADS()) { ?>
                        <!-- automaticke vlozeni prestavek -->
                        <input type="button" class="button confirmQuestion" name="prestavkyproden" value="<?= TextManager::_('Vlozit_prestavky') ?>"
                               data-ron-href="?menuid=editacedne&action=prestavkyproden&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_vlozit_prestavky' : '' ?>"
                               data-ron-working-info="<?= TextManager::_('Probiha_zpracovani_dat') ?>" />

                        <!-- prepocet podle puvodni dochazky -->
                        <input type="button" class="button confirmQuestion" name="podlepuvodni" value="<?= TextManager::_('Podle_puvodni_dochazky') ?>"
                               data-ron-href="?menuid=editacedne&action=podlepuvodni&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_podle_puvodni' : '' ?>"
                               data-ron-working-info="<?= TextManager::_('Probiha_zpracovani_dat') ?>" />

                        <!-- vlozeni podle kalendare -->
                        <input type="button" class="button confirmQuestion" name="podlekalendare" value="<?= TextManager::_('Podle_kalendare') ?>"
                               data-ron-href="?menuid=podlekalendare&idpp=<?= $this ->pp ->idPP ?>&datum=<?= DateUtils::dateToUrlString($this ->den) ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_podle_kalendare' : '' ?>" />

                <?php } ?>
            </div>

            <div>
                <?php $this ->zobrazRozdeleniVysledku(); ?>
            </div>

            <?php if ($this ->vyrobaForm) { ?>
                <div class="form-gap"></div>
                <?php $this ->vyrobaForm ->render(); ?>
            <?php } ?>

        </div>


        <div class="buttons">
            <?php if (!$this ->readOnly  ||  $this ->povolitEditaciRozdeleni) { ?>
                <!-- tlacitka -->

                <div class="row">
                    <div class="col col-6">
                        <input type="submit" class="submitbutton" value="<?= TextManager::_('OK') ?>">
                    </div>
                    <div class="col col-6 align-right">
                        <span style="padding:15px"><a href='<?= $backurl ?>'><?= TextManager::_('Zpet') ?></a></span>
                        <!-- prestavky, puvodni, kalendar -->
                    </div>
                </div>

            <?php } else { ?>
                <div class="row">
                    <div class="align-right">
                        <a href='<?= $backurl ?>'><?= TextManager::_('Zpet') ?></a>
                    </div>
                </div>
            <?php } ?>
        </div>
    </div>

</form>

<?php GuiUtils::scrollPageScript(); ?>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/view_editace_dne.php <==
<?php

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\RonPortalSettings;
use RonPortal\Security;

/** @var $this EditaceDneFormular */

$readonlystr = $this ->readOnly ? ' disabled="disabled" ' : '';

$backurl =
    '?menuid=' . ((isset($_SESSION['editace_backaction']) && $_SESSION['editace_backaction'] == 'rozdelenidv') ? 'rozdelenidv' : 'zpracovanadochazka') .
    '&idpp=' . $this ->pp ->idPP .
    '&obdobi=' . DateUtils::dateToUrlString(DateUtils::firstDayOfMonth($this ->den));

?>
<h1><?= TextManager::_('Editace_dochazky') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<form enctype="multipart/form-data" method="post" id="editaceDneForm" action="?menuid=editacedne&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>" class="sendPosition" >
    <!-- skryty submit button, protoze defaultni submit musi byt vzdy prvni (jinak by byl defaultni button pro smazani radku rozdeleni) -->
    <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" />

    <input type="hidden" name="idpp" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="datum" value="<?= $this ->den ?>" />
    <input type="hidden" name="ulozzaznamyproden" value="<?= $this ->readOnly ? 0 : 1 ?>" />
    <input type="hidden" name="ulozrozdelenivysledku" value="<?= $this ->povolitEditaciRozdeleni ? 1 : 0 ?>" />
    <input type="hidden" name="pocet" value="<?= count($this ->zaznamy) ?>" />
    <input type="hidden" name="zobrazitnovy" value="<?= $this ->zobrazitNovy ?>" />
    <input type="hidden" name="deleterow" id="editaceDneDeleteRow" value="" />
    <input type="hidden" name="x" />
    <input type="hidden" name="y" />

    <?= Security::csrfHiddenInput() ?>

    <div class="form form-sm large-form" id="editaceDne">
        <div class="form-content">
            <!-- hlavicka -->
            <div class="row">
                <div class="col col-12 col-sm-3" style="white-space:nowrap">
                    <?php $this->zobrazSchvaleni($this->den); ?>
                </div>

                <div class="col col-7 d-xs-none">
                </div>

                <div class="col col-2 d-xs-none formFotoContainer">
                    <!-- foto -->
                    <?php if ($this ->pp ->idFotografie) { ?>
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    <?php } ?>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7">
                    <strong><?= $this->pp ->jmenoPrijmeni ?></strong>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-7">
                    <strong><?= TextManager::_('Day_short_' . date("w", $this ->den)) . ' ' . date('j.n.Y', $this ->den) ?></strong>
                    <?php if ($this ->obdobiUzavreno) { ?><div class="inline-glyph fa glyph-lock"></div><?php } ?>
                </div>
            </div>

            <div class="row form-gap d-xs-none">&nbsp;</div>

            <!-- zaznamy -->
            <div class="row form-section no-margin-bottom">
                <div class="col col-1"><?= TextManager::_('Od') ?></div>
                <div class="col col-1"><?= TextManager::_('Do') ?></div>
                <div class="col col-10"></div>
            </div>

            <?php foreach ($this ->zaznamy as $i => $zaznam) {

            $rowclassname = ($i % 2) ? 'browsercolor1' : 'browsercolor2';

            $classname_od = $zaznam ->chybaCasPocatku ? 'error' : '';
            $classname_do = $zaznam ->chybaCasKonce ? 'error' : '';
            ?>

                <div class="zaznamEditaceDne <?= $rowclassname ?>">
                    <div class="row">
                        <!-- cas od-do -->
                        <div class="col col-1">
                            <input type="hidden" name="datumcaspocatku<?= $i ?>" value="<?= $zaznam ->fDatumCasPocatku ->originalValue /* puvodni datum cas pocatku */ ?>" />
                            <input type="hidden" name="datumpocatku<?= $i ?>" value="<?= date('j.n.Y', $zaznam->fDatumCasPocatku ->value) ?>" /> <!-- pro js -->
                            <input type="text" class="form-input <?= $classname_od ?> inputTime" name="caspocatku<?= $i ?>" maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->casPocatkuStr) ?>" />
                        </div>
                        <div class="col col-1">
                            <input type="text" class="form-input <?= $classname_do ?> inputTime" name="casukonceni<?= $i ?>" maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->casKonceStr) ?>" />
                        </div>

                        <!-- den prirazeni -->
                        <div class="col col-2 caption"><?= TextManager::_('Den_prirazeni') ?></div>
                        <div class="col col-5">
                            <input type="text" class="<?= $zaznam->chybaDen ? 'error' : '' ?> inputDate" name="den<?= $i ?>"
                                   maxlength="10" size="10" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->denStr) ?>"
                                   data-roncalendar-mindate="<?= date('j.n.Y', DateUtils::incDay($zaznam ->fDatumCasPocatku ->value, -1) ) ?>"
                                   data-roncalendar-maxdate="<?= date('j.n.Y', DateUtils::incDay($zaznam ->fDatumCasPocatku ->value, 1) ) ?>"
                                />
                            <i class="inline-glyph glyph-button fa glyph-calendar showcalendar" data-roncalendar-inputname="den<?= $i ?>"></i>
                        </div>
                        <div class="col col-2 align-right">
                            <?= StringUtils::htmlTextConvert($zaznam ->fZpracoval ->value) ?>
                        </div>
                        <div class="col col-1 align-right">
                            <?php if (!$this ->readOnly) { ?>
                            <i class="inline-glyph glyph-button fa glyph-delete deleteRecord" data-index="<?= $i ?>"  data-ron-confirm-text="<?= TextManager::_('Opravdu_smazat_zaznam_dochazky') ?>"></i>
                            <?php } ?>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col col-2"><?= RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY) ? '' : TextManager::_('Zapocteno') ?></div>

                        <!-- operace -->
                        <div class="col col-2 caption"><?= TextManager::_('Operace') ?></div>
                        <div class="col col-5">
                            <?php $this->showVyberOperace($zaznam ->fOperace ->value, $i, false); ?>
                        </div>
                        <div class="col col-3">
                            <?php $this->showVyberOperace($zaznam ->fOperace ->value, $i, true); ?>
                        </div>
                    </div>


                    <div class="row">
                        <!-- zapocteny cas -->
                        <div class="col col-1">
                            <?php if (!RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY)) { ?>
                                <input type="text" class="form-input <?= $zaznam->chybaZapoctenyCasOd ? 'error' : '' ?>" name="zapoctenycasod<?= $i ?>"
                                       maxlength="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->zapoctenyCasOdStr) ?>" />
                            <?php } ?>
                        </div>
                        <div class="col col-1">
                            <?php if (!RonPortalSettings::getIntValue(ZaznamDochazky::SETTINGS_SKRYT_ZAPOCTENY)) { ?>
                                <input type="text" class="form-input <?= $zaznam->chybaZapoctenyCasDo ? 'error' : '' ?>" name="zapoctenycasdo<?= $i ?>"
                                       maxlength="5" size="5" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam->zapoctenyCasDoStr) ?>" />
                            <?php } ?>
                        </div>

                        <div class="col col-2 caption"><?= TextManager::_('Smena') ?></div>
                        <div class="col col-8"><?php  $this ->showVyberSmeny($zaznam, 'smena' . $i); ?></div>
                    </div>

                    <?php
                    // pripadne jeste stredisko (rozdeleni)
                    if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) { ?>
                        <div class="row">
                            <div class="col col-2 d-xs-none"></div>

                            <!-- vyber rozdeleni -->
                            <div class="col col-12 col-sm-2 caption"><?= RonPortalSettings::getValue(RonPortalSettings::EDITACE_NADPIS_ROZDELENI) ?: TextManager::_('Rozdeleni') ?></div>
                            <div class="col col-8 col-sm-5">
                                <?php $this->showVyberRozdeleni($zaznam, 'rozdelenidochazky' . $i, false); ?>
                            </div>
                            <div class="col col-4 col-sm-3">
                                <?php $this->showVyberRozdeleni($zaznam, 'rozdelenidochazky' . $i, true); ?>
                            </div>
                        </div>
                    <?php } ?>

                    <div class="row">
                        <div class="col col-2 d-xs-none"></div>

                        <div class="col col-12 col-sm-2 caption"><?= TextManager::_('Poznamka') ?></div>
                        <div class="col col-12 col-sm-8">
                            <input type="text" class="form-input" name="poznamka<?= $i ?>" maxlength="160" <?= $readonlystr ?> value="<?= StringUtils::htmlTextConvert($zaznam ->poznamka) ?>" />
                        </div>
                    </div>
                </div>
            <?php } ?>

            <div class="align-right">
                <?php if (!$this ->readOnly  &&  RonPortalSettings::getSpousteniADS()) { ?>
                        <!-- automaticke vlozeni prestavek -->
                        <input type="button" class="button confirmQuestion" name="prestavkyproden" value="<?= TextManager::_('Vlozit_prestavky') ?>"
                               data-ron-href="?menuid=editacedne&action=prestavkyproden&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_vlozit_prestavky' : '' ?>"
                               data-ron-working-info="<?= TextManager::_('Probiha_zpracovani_dat') ?>" />

                        <!-- prepocet podle puvodni dochazky -->
                        <input type="button" class="button confirmQuestion" name="podlepuvodni" value="<?= TextManager::_('Podle_puvodni_dochazky') ?>"
                               data-ron-href="?menuid=editacedne&action=podlepuvodni&idpp=<?= $this ->pp ->idPP ?>&datum=<?= $this ->den ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_podle_puvodni' : '' ?>"
                               data-ron-working-info="<?= TextManager::_('Probiha_zpracovani_dat') ?>" />

                        <!-- vlozeni podle kalendare -->
                        <input type="button" class="button confirmQuestion" name="podlekalendare" value="<?= TextManager::_('Podle_kalendare') ?>"
                               data-ron-href="?menuid=podlekalendare&idpp=<?= $this ->pp ->idPP ?>&datum=<?= DateUtils::dateToUrlString($this ->den) ?>"
                               data-ron-confirm-id="<?= count($this ->zaznamy) ? 'Opravdu_podle_kalendare' : '' ?>" />

                <?php } ?>
            </div>

            <div>
                <?php $this ->zobrazRozdeleniVysledku(); ?>
            </div>

            <?php if ($this ->vyrobaForm) { ?>
                <div class="form-gap"></div>
                <?php $this ->vyrobaForm ->render(); ?>
            <?php } ?>

        </div>


        <div class="buttons">
            <?php if (!$this ->readOnly  ||  $this ->povolitEditaciRozdeleni) { ?>
                <!-- tlacitka -->

                <div class="row">
                    <div class="col col-6">
                        <input type="submit" class="submitbutton" value="<?= TextManager::_('OK') ?>">
                    </div>
                    <div class="col col-6 align-right">
                        <span style="padding:15px"><a href='<?= $backurl ?>'><?= TextManager::_('Zpet') ?></a></span>
                        <!-- prestavky, puvodni, kalendar -->
                    </div>
                </div>

            <?php } else { ?>
                <div class="row">
                    <div class="align-right">
                        <a href='<?= $backurl ?>'><?= TextManager::_('Zpet') ?></a>
                    </div>
                </div>
            <?php } ?>
        </div>
    </div>

</form>

<?php GuiUtils::scrollPageScript(); ?>
